@@ -1,4 +1,5 @@
 # Copyright (c) 2023 Damien Nadé
+# Copyright (c) 2025 Steve Hespelt
 # Copyright (c) 2024 Adam Karpierz
 # SPDX-License-Identifier: LGPL-2.1-or-later
 
@@ -6,13 +7,14 @@
 
 from .__about__ import * ; del __about__  # type: ignore[name-defined]  # noqa
 
+from tox.config.cli.parser import ToxParser
 from tox.config.sets import EnvConfigSet
 from tox.plugin import impl
 from tox.session.state import State
 from tox.tox_env.api import ToxEnv
 
-from .backquote import SHELL, has_backticks, \
-    eval_backquote, set_env_backquote_items
+from .backquote import (SHELL, has_backticks,
+    eval_backquote, set_env_backquote_items)
 from .setenv import set_env_items
 
 
@@ -32,5 +34,21 @@ def tox_add_env_config(env_conf: EnvConfigSet, state: State) -> None:
 def tox_before_run_commands(tox_env: ToxEnv) -> None:
     """Eval and replace backquotes expressions"""
     set_env = tox_env.conf["set_env"]
-    set_env.update({var: eval_backquote(tox_env, cmd, var)
+    dont_strip_nl = (tox_env.options.backtick_no_strip
+                     if "backtick_no_strip" in tox_env.options else False)
+    set_env.update({var: eval_backquote(tox_env, cmd, var, not dont_strip_nl)
                     for var, cmd in set_env_backquote_items(set_env)})
+
+
+@impl
+def tox_add_option(parser: ToxParser) -> None:
+    # have to get the parser for commands that need evaluations of set_env backticks ?
+    for cmd in ("run", "exec", "run-parallel", "legacy"):
+        run_parser = parser.handlers[cmd]
+        if run_parser:
+            run_parser[0].add_argument(
+                "--backtick-no-strip",  # default is to strip out the \n\r chars
+                action="store_true",
+                help="do not strip out LF, CR characters from backtick results",
+                dest="backtick_no_strip"
+            )
